@@ -16,11 +16,11 @@ Astro::DSS::JPEG - Download color JPEG images from the Digitized Sky Survey
 
 =head1 VERSION
 
-Version 0.01_1
+Version 0.02
 
 =cut
 
-our $VERSION = '0.01_1';
+our $VERSION = '0.02';
 
 
 =head1 SYNOPSIS
@@ -68,9 +68,9 @@ an object name/id instead of coordinates.
     );
   
 All parameters are optional. The constructor by default creates an L<LWP::UserAgent>,
-but you can pass your own with C<ua>, while the URL to the STScI JPEG endpoint
-and the L<SIMBAD|http://simbad.u-strasbg.fr/simbad/> simple id interface can be redefined
-(e.g. if they change in the future) from the above shown defaults.
+but you can pass your own with C<ua>, while the URL to the L<STScI|https://archive.stsci.edu/dss/copyright.html>
+JPEG endpoint and the L<SIMBAD|http://simbad.u-strasbg.fr/simbad/> simple identifier query
+interface can be redefined (e.g. if they change in the future) from the above shown defaults.
 
 =head1 METHODS
 
@@ -179,16 +179,17 @@ sub get_image {
         );
     }
 
-    my $res = $self->_getDSS(_process_options(%opts));
+    my $res = $self->_get_dss(_process_options(%opts));
     if ($res->is_success) {
         return $res if $opts{filename};
         return $res->decoded_content;
     } else {
-        die "*ERROR* Could not access DSS:\n".$res->status_line;
+        die "*ERROR* Could not access DSS at: ".$res->request->uri
+            ."\nHTTP Response:\n".$res->status_line;
     }
 }
 
-sub _getDSS {
+sub _get_dss {
     my ($self, %opts) = @_;
 
     my @request = (
@@ -260,7 +261,9 @@ sub _get_simbad {
             $opts{angular_size} = min($1 * 1.5, 600); # Get 50% extra for framing, max out at 10 degrees
         }
     } else {
-        die "*ERROR* Could not access SIMBAD:\n".$res->status_line;
+        die "*ERROR* Could not access SIMBAD at: "
+            .$self->{simbad_url}."?output.format=ASCII&Ident=".$opts{target}
+            ."\nHTTP response:\n".$res->status_line;
     }
 
     return \%opts;
